two_columns.pdf

## Metadata

Title | two_columns.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\two_columns.pdf
Pages | 0
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230325084750+00'00'
PDF Metadata: modDate | D:20230325084750+00'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0
2. h2 :: A Test Document

#### Page 0

No images

Path: | content.0.[0,0].bbox
Type: | addition

Key | Old | New
x1 |  | 219.25999450683594
y1 |  | 94.96131134033203
y0 |  | 74.92131042480469
x0 |  | 72.02400207519531

Path: | content.0.[3,3].bbox
Type: | addition

Key | Old | New
x1 |  | 282.083984375
y1 |  | 730.3276977539062
y0 |  | 552.7077026367188
x0 |  | 72.02400207519531

Path: | content.0.[2,2].bbox
Type: | addition

Key | Old | New
x1 |  | 282.2040100097656
y1 |  | 536.9577026367188
y0 |  | 304.1377258300781
x0 |  | 72.02400207519531

Path: | content.0.[4,4].bbox
Type: | addition

Key | Old | New
x1 |  | 525.6460571289062
y1 |  | 306.5377502441406
y0 |  | 73.70773315429688
x0 |  | 315.42999267578125

Path: | content.0.[5,5].bbox
Type: | addition

Key | Old | New
x1 |  | 515.4339599609375
y1 |  | 472.2777099609375
y0 |  | 322.2577209472656
x0 |  | 315.42999267578125

Path: | content.0.[6,6].bbox
Type: | addition

Key | Old | New
x1 |  | 523.4260864257812
y1 |  | 651.9476928710938
y0 |  | 488.11773681640625
x0 |  | 315.42999267578125

Path: | content.0.[7,7].bbox
Type: | addition

Key | Old | New
x1 |  | 525.6099853515625
y1 |  | 762.607666015625
y0 |  | 667.7877197265625
x0 |  | 315.42999267578125

## A Test Document

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur egestas tellus ut ante dictum accumsan. Curabitur vel imperdiet tortor, vestibulum accumsan libero. Ut ac elementum nulla. Ut sit amet faucibus risus. Curabitur maximus urna non lectus bibendum finibus. Duis eget eleifend sapien. Suspendisse potenti. Donec neque lorem, scelerisque non sollicitudin sed, molestie a eros. Donec sed turpis sit amet dui vestibulum fringilla. Integer ut enim sit amet sem vestibulum efficitur et vel ante.

Suspendisse commodo condimentum dolor, eu consectetur dui posuere sed. Curabitur eros sem, venenatis consectetur ultricies in, vehicula sodales felis. Donec sem est, pulvinar ac justo sed, posuere malesuada justo. Vivamus sagittis at tortor vitae sodales. Donec sit amet egestas nulla. Cras eget auctor libero. Donec at maximus metus. Aliquam nec dolor euismod, lobortis purus et, rhoncus sem. Phasellus a dolor et lacus dapibus efficitur. Cras diam mi, consectetur vitae blandit a, consectetur ac mi. Etiam arcu eros, finibus eget elementum ut, ultricies nec metus. Ut eget sagittis turpis, a dignissim orci. Nunc vestibulum dui sed commodo congue. Praesent ultrices mattis tortor.

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur egestas tellus ut ante dictum accumsan. Curabitur vel imperdiet tortor, vestibulum accumsan libero. Ut ac elementum nulla. Ut sit amet faucibus risus. Curabitur maximus urna non lectus bibendum finibus. Duis eget eleifend sapien. Suspendisse potenti. Donec neque lorem, scelerisque non sollicitudin sed, molestie a eros. Donec sed turpis sit amet dui vestibulum fringilla. Integer ut enim sit amet sem vestibulum efficitur et vel ante.

Suspendisse commodo condimentum dolor, eu consectetur dui posuere sed. Curabitur eros sem, venenatis consectetur ultricies in, vehicula sodales felis. Donec sem est, pulvinar ac justo sed, posuere malesuada justo. Vivamus sagittis at tortor vitae sodales. Donec sit amet egestas nulla. Cras eget auctor libero. Donec at maximus metus. Aliquam nec dolor euismod, lobortis purus et, rhoncus sem. Phasellus a dolor et lacus dapibus efficitur. Cras diam mi, consectetur vitae blandit a, consectetur ac mi. Etiam arcu eros, finibus eget elementum ut, ultricies nec metus. Ut eget sagittis turpis, a dignissim orci. Nunc vestibulum dui sed commodo congue. Praesent ultrices mattis tortor.

Aliquam diam neque, eleifend ac mauris sit amet, molestie finibus odio. Phasellus sagittis est sem, non aliquam mi porta ut. Ut sodales lectus ut ultrices tristique. Nullam nec pulvinar ex. Quisque fermentum nisl quis est volutpat dictum. Curabitur aliquam ex a sapien faucibus tempor. Etiam accumsan tempus turpis a aliquet. In nec eros nunc. Phasellus sit amet varius erat. Mauris dictum egestas sodales.

Mauris at turpis luctus, congue nisi ac, vehicula magna. Cras aliquam tristique dapibus. Cras enim ex, accumsan vel sodales ut, mattis in neque. Ut semper nulla vel consequat vulputate. Vivamus ullamcorper, purus et tempor sagittis, risus lorem convallis dolor, a maximus dolor nulla in dolor. Vivamus ut neque ultricies justo lacinia mollis quis sit amet nisl. Suspendisse nec varius ligula, posuere facilisis quam. Donec sit amet maximus lacus.

Praesent faucibus hendrerit ex eget feugiat. Nunc nec mi placerat, fermentum dolor quis, vulputate sem. Aliquam pellentesque metus in risus dapibus suscipit. Quisque ut ultricies orci. Praesent sit amet faucibus ante. Proin vel fringilla lectus. Vivamus at interdum sem. Ut in tellus semper, mollis.

## A Test Document

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur egestas tellus ut ante dictum accumsan. Curabitur vel imperdiet tortor, vestibulum accumsan libero. Ut ac elementum nulla. Ut sit amet faucibus risus. Curabitur maximus urna non lectus bibendum finibus. Duis eget eleifend sapien. Suspendisse potenti. Donec neque lorem, scelerisque non sollicitudin sed, molestie a eros. Donec sed turpis sit amet dui vestibulum fringilla. Integer ut enim sit amet sem vestibulum efficitur et vel ante.

Suspendisse commodo condimentum dolor, eu consectetur dui posuere sed. Curabitur eros sem, venenatis consectetur ultricies in, vehicula sodales felis. Donec sem est, pulvinar ac justo sed, posuere malesuada justo. Vivamus sagittis at tortor vitae sodales. Donec sit amet egestas nulla. Cras eget auctor libero. Donec at maximus metus. Aliquam nec dolor euismod, lobortis purus et, rhoncus sem. Phasellus a dolor et lacus dapibus efficitur. Cras diam mi, consectetur vitae blandit a, consectetur ac mi. Etiam arcu eros, finibus eget elementum ut, ultricies nec metus. Ut eget sagittis turpis, a dignissim orci. Nunc vestibulum dui sed commodo congue. Praesent ultrices mattis tortor.

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur egestas tellus ut ante dictum accumsan. Curabitur vel imperdiet tortor, vestibulum accumsan libero. Ut ac elementum nulla. Ut sit amet faucibus risus. Curabitur maximus urna non lectus bibendum finibus. Duis eget eleifend sapien. Suspendisse potenti. Donec neque lorem, scelerisque non sollicitudin sed, molestie a eros. Donec sed turpis sit amet dui vestibulum fringilla. Integer ut enim sit amet sem vestibulum efficitur et vel ante.

Suspendisse commodo condimentum dolor, eu consectetur dui posuere sed. Curabitur eros sem, venenatis consectetur ultricies in, vehicula sodales felis. Donec sem est, pulvinar ac justo sed, posuere malesuada justo. Vivamus sagittis at tortor vitae sodales. Donec sit amet egestas nulla. Cras eget auctor libero. Donec at maximus metus. Aliquam nec dolor euismod, lobortis purus et, rhoncus sem. Phasellus a dolor et lacus dapibus efficitur. Cras diam mi, consectetur vitae blandit a, consectetur ac mi. Etiam arcu eros, finibus eget elementum ut, ultricies nec metus. Ut eget sagittis turpis, a dignissim orci. Nunc vestibulum dui sed commodo congue. Praesent ultrices mattis tortor.

Aliquam diam neque, eleifend ac mauris sit amet, molestie finibus odio. Phasellus sagittis est sem, non aliquam mi porta ut. Ut sodales lectus ut ultrices tristique. Nullam nec pulvinar ex. Quisque fermentum nisl quis est volutpat dictum. Curabitur aliquam ex a sapien faucibus tempor. Etiam accumsan tempus turpis a aliquet. In nec eros nunc. Phasellus sit amet varius erat. Mauris dictum egestas sodales.

Mauris at turpis luctus, congue nisi ac, vehicula magna. Cras aliquam tristique dapibus. Cras enim ex, accumsan vel sodales ut, mattis in neque. Ut semper nulla vel consequat vulputate. Vivamus ullamcorper, purus et tempor sagittis, risus lorem convallis dolor, a maximus dolor nulla in dolor. Vivamus ut neque ultricies justo lacinia mollis quis sit amet nisl. Suspendisse nec varius ligula, posuere facilisis quam. Donec sit amet maximus lacus.

Praesent faucibus hendrerit ex eget feugiat. Nunc nec mi placerat, fermentum dolor quis, vulputate sem. Aliquam pellentesque metus in risus dapibus suscipit. Quisque ut ultricies orci. Praesent sit amet faucibus ante. Proin vel fringilla lectus. Vivamus at interdum sem. Ut in tellus semper, mollis.

Parent File Contents